import 'dart:convert';
import 'dart:io';
import 'package:amap_flutter_location/amap_flutter_location.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:get_storage/get_storage.dart';
import 'package:worker_client/services/amap.dart';
import 'package:worker_client/services/user.dart';
import 'entities/person.dart';
import '/widgets/Modal.dart';
import '../utils/location.dart';

class AppController extends GetxController {
  // 有了这句, 可以直接 AppController.t 调用
  static AppController t = Get.find();
  GetStorage box = GetStorage();
  final user = Rx<Person>(Person());
  final location = Rxn<Map<String, Object>>();
  final address = Rxn<Map<String, Object>>({'address': ''});
  final testInt = 1.obs;

  AMapFlutterLocation? _location;

  get locationStr {
    if (null == location.value) return null;

    double longitude = location.value!['longitude'] as double;
    double latitude = location.value!['latitude'] as double;

    return longitude.toString() + "," + latitude.toString();
  }

  void onLocationChange(Map<String, Object> result) {
    if (result['errorCode'] == null) {
      location(result);
      if (address.value!['address'] == '' &&
          box.read('token') != null &&
          location.value!['longitude'] != null) {
        setAmap({
          //定位有问题
          'params':
              'location=${result['longitude'].toString()},${result['latitude'].toString()}',
          // 'params': 'location=116.397128,39.916527',
          'path': '/v3/geocode/regeo'
        }).then((value) {
          //json字符串转Map对象
          address(
              {'address': jsonDecode(value)['regeocode']['formatted_address']});
        });
      }
    }
  }

  @override
  void onInit() {
    super.onInit();
    //尝试获取 location
    requireLocation(onLocationChange).then((loc) {
      _location = loc;
    }).catchError((e) {
      print(e);

      showAlert(
        title: '获取定位失败',
        message: e.message,
        onConfirm: () => exit(1),
      );
    });

    if (box.read('token') != null) {
      // 尝试获取一次人员信息
      getCurrent().then((person) {
        user(Person.fromJson(person));
      });
    }
  }

  @override
  void onClose() {
    if (null != _location) {
      _location?.destroy();
    }
  }
}
