import 'dart:convert';

import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:carousel_slider/carousel_slider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:worker_client/models/app.dart';
import 'package:worker_client/models/entities/Banner.dart';
import 'package:worker_client/models/entities/Job.dart';
import 'package:worker_client/pages/home/widgets/headers.dart';
import 'package:worker_client/services/amap.dart';
import 'package:worker_client/services/banner.dart';
import 'package:worker_client/services/job.dart';
import 'package:worker_client/widgets/MyCard/index.dart';
import 'package:worker_client/widgets/RefreshMoreList.dart';
import 'package:worker_client/widgets/layout/BasicPage.dart';
import '/widgets/MyDialog.dart' as modal;

class Home extends BasicPage {
  Home({Key? key}) : super(key: key) {
    tabIndex = 0;
    naviTitle = '首页';
  }

  final bannerList = Rx<List<BannerModel>>([]);
  final jobList = Rx<List<Job>>([]);
  final job = Rx<Job>(Job());
  final area = Rx<String>('');
  final params = Rx<Map<String, dynamic>>({'pageSize': 10});
  Function? Refresh;

  void beforeShow() {
    super.beforeShow();

    getBannerList('bannerWorker').then((res) {
      List<BannerModel> list = [];
      for (var item in res) {
        list.add(BannerModel.fromJson(item));
      }
      bannerList.value = list;
    });
  }

  List<Job> GetList(value) {
    List<Job> list = [];
    if (value != null) value.forEach((item) => {list.add(Job.fromJson(item))});
    return list;
  }

  void goDetail(Job item) {
    Get.toNamed('/jobDetail', arguments: {'id': item.jobId});
  }

  void changeList(Job item) {
    List<Job> list = [];
    for (var e in jobList.value) {
      if (e.jobId == item.jobId) {
        if (item.status == 0) {
          e.status = 1;
        } else if (item.status == 1) {
          e.status = 3;
        }
      }
      list.add(e);
    }
    jobList(list);
  }

  Widget startContent() {
    return Column(
      children: [
        Image.asset(
          'images/index/positionImg.png',
          width: 40.w,
        ),
        Container(
          alignment: Alignment.centerLeft,
          margin: EdgeInsets.fromLTRB(65.w, 26.h, 65.w, 0),
          child: Text(
            '当前位置在',
            style: TextStyle(
              fontSize: 17.sp,
              fontWeight: FontWeight.w800,
              color: const Color(0xff323232),
            ),
          ),
        ),
        Container(
          margin: EdgeInsets.fromLTRB(65.w, 0, 65.w, 50.h),
          child: Text(
            AppController.t.address.value!['address'].toString(),
            style: TextStyle(
              fontSize: 17.sp,
              fontWeight: FontWeight.w800,
              color: const Color(0xff323232),
            ),
          ),
        ),
      ],
    );
  }

  Widget endContent() {
    return Container(
      margin: EdgeInsets.fromLTRB(15.w, 0, 15.w, 25.h),
      padding: EdgeInsets.symmetric(vertical: 18.h, horizontal: 15.w),
      decoration: BoxDecoration(
          border: Border.all(
              width: 1.w,
              style: BorderStyle.solid,
              color: const Color(0xFFF2F2F2)),
          borderRadius: BorderRadius.all(Radius.circular(20.w))),
      child: Row(
        children: [
          Text(
            '作业面积：',
            style: TextStyle(
              fontSize: 17.sp,
              fontWeight: FontWeight.w500,
              color: const Color(0xff333333),
            ),
          ),
          Expanded(
            child: TextField(
              keyboardType: TextInputType.number,
              style: TextStyle(fontSize: 16.sp),
              decoration: const InputDecoration(
                isCollapsed: true,
                hintText: '请输入本次作业的面积',
                border: InputBorder.none,
                counterText: '', //去掉计数
                floatingLabelBehavior: FloatingLabelBehavior.never,
              ),
              onChanged: (e) {
                area(e);
              },
            ),
          ),
          Text(
            '/亩',
            style: TextStyle(
              fontSize: 17.sp,
              fontWeight: FontWeight.w500,
              color: const Color(0xff333333),
            ),
          ),
        ],
      ),
    );
  }

  void changeJob(Job item) {
    if (item.status == 0) {
      modal.showDialog(
          content: startContent(),
          onConfirm: () {
            EasyLoading.show(status: '请稍后');
            startJob(item.jobId.toString(), {'mode': true}).then((value) {
              //关闭弹窗需要改变列表
              changeList(item);
              EasyLoading.dismiss();
            }).catchError((error) {
              Fluttertoast.showToast(msg: error.error['message']);
              EasyLoading.dismiss();
            });
          });
    } else {
      modal.showDialog(
        content: endContent(),
        onConfirm: () {
          if (area.value == '') {
            Fluttertoast.showToast(msg: '请输入正确的面积整数或最多两位小数');
            return false;
          } else {
            EasyLoading.show(status: '请稍后');
            overJob(item.jobId.toString(), {
              ...item.toJson(),
              'area': area.value.toString()
            }).then((value) {
              //关闭弹窗需要改变列表
              changeList(item);
              EasyLoading.dismiss();
              Fluttertoast.showToast(msg: '恭喜完成作业');
            }).catchError((error) {
              Fluttertoast.showToast(msg: error.error['message']);
              EasyLoading.dismiss();
            });
          }
        },
      );
    }
  }

  @override
  Widget builder(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(color: Colors.white),
      padding: EdgeInsets.only(top: 15.w, left: 15.w, right: 15.w),
      child: RefreshMoreList(
        pPrams: params,
        cardText: '暂无订单',
        fetch: getJobList,
        isHome: true,
        useState: (state) {
          jobList(GetList(state));
        },
        builder: ({required BuildContext context, required Function toggle}) {
          Refresh = toggle;
          return Column(
            children: [
              const headers(),
              //banner
              Container(
                margin: EdgeInsets.fromLTRB(0, 15.h, 0, 15.h),
                child: Obx(() => CarouselSlider(
                      items: bannerList.value
                          .map((item) => Center(
                              child: Image.network(item.thumb.toString(),
                                  fit: BoxFit.cover, width: 345.w)))
                          .toList(),
                      options: CarouselOptions(
                        autoPlay: true,
                        enlargeCenterPage: false,
                        //图片中心放大
                        viewportFraction: 1,
                        //每个页面应占据的视口部分。默认为 0.8，这意味着每个页面填充 80% 的轮播。
                        // aspectRatio: 1.6,//纵横比
                        height: 214.w,
                        initialPage: 1, //初始页
                      ),
                    )),
              ),
              Container(
                margin: EdgeInsets.fromLTRB(0, 15.h, 0, 20.h),
                child: Row(
                  children: [
                    Padding(
                      padding: EdgeInsets.fromLTRB(0, 0, 10.w, 0),
                      child: Image.asset(
                        'images/index/orderList.png',
                        width: 20.w,
                      ),
                    ),
                    Text(
                      '作业列表',
                      style: TextStyle(
                          color: Color(0xff222222),
                          fontSize: 20.sp,
                          fontWeight: FontWeight.w800),
                    )
                  ],
                ),
              ),
              Obx(
                () => Column(
                  children: jobList.value
                      .map(
                        (item) => MyCard(
                          item: item,
                          job: true,
                          detail: false,
                          onClick: () {
                            changeJob(item);
                          },
                          goDetail: () {
                            goDetail(item);
                          },
                          buttomText: item.status == 0 ? '开始作业' : '完成作业',
                        ),
                      )
                      .toList(),
                ),
              )
            ],
          );
        },
      ),
    );
  }
}
