import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:worker_client/models/app.dart';
import 'package:worker_client/models/entities/Machinery.dart';
import 'package:worker_client/services/amap.dart';
import 'package:worker_client/services/machinery.dart';
import 'package:worker_client/widgets/amap/amap.dart';
import 'package:worker_client/widgets/layout/BasicPage.dart';

class MachineryMap extends BasicPage {
  MachineryMap({Key? key}) : super(key: key);
  String? location = AppController.t.locationStr;
  final machineryList = Rx<List<Machinery>>([]);
  //用来放地图中心的
  final machinery = Rx<Machinery>(Machinery());
  //切换农机时用的当前农机变量
  final current = Rx<Machinery>(Machinery());
  final visible = Rx<bool>(true);

  dynamic locList = [
    '32.685927, 112.106514',
    '32.673406, 112.100406',
    '32.670488, 112.06397',
    '32.685684, 112.05434',
    '32.701302, 112.058724',
    '32.665504, 112.015102',
    '32.685502, 112.010503',
    '32.651764, 112.097747',
    '32.664957, 112.149705',
    '32.701241, 112.16185',
  ];
  @override
  void beforeShow() {
    super.beforeShow();
    if (Get.arguments != null) {
      EasyLoading.show(status: '数据加载中...');
      getMachineryDetail(Get.arguments['id'], {
        'attached': true,
        //查询农机详情时需要把当前定位传到服务端
        'location': location
      })
          .then((res) => {
                getMachineryList({'pageSize': 500, 'location': location})
                    .then((value) {
                  dynamic list = <Machinery>[];
                  int index;
                  Machinery data = Machinery.fromJson(res);
                  List area = [];
                  value['records'].forEach((item) {
                    index = value['records'].indexOf(item);
                    item['location'] = locList[index % 10];
                    list.add(Machinery.fromJson(item));
                    if (data.machineryId == item['machineryId']) {
                      data.location = item['location'];
                      area = item['location'].toString().split(',');
                      setAmap({
                        'params': 'location=${area[1]},${area[0]}',
                        'path': '/v3/geocode/regeo'
                      }).then((value) {
                        //json字符串转Map对象
                        data.address =
                            jsonDecode(value)['regeocode']['formatted_address'];
                        machinery(data);
                        current(data);
                      });
                    }
                  });
                  machineryList(list);
                  EasyLoading.dismiss();
                }).catchError((error) {
                  EasyLoading.dismiss();
                  Fluttertoast.showToast(msg: error.error['message']);
                }),
              })
          .catchError((error2) {
        EasyLoading.dismiss();
        Fluttertoast.showToast(msg: error2.error['message']);
      });
    }
  }

  void goBack() {
    Get.back();
  }

  void goDetail() {
    Get.toNamed('/machineryDetail',
        arguments: {'id': current.value.machineryId});
  }

  void onClick(e) {
    List area = e.location.toString().split(',');
    if (e.address == null) {
      setAmap({
        //定位有问题
        'params': 'location=${area[1]},${area[0]}',
        'path': '/v3/geocode/regeo'
      }).then((value) {
        //json字符串转Map对象
        e.address = jsonDecode(value)['regeocode']['formatted_address'];
        current(e);
        visible(true);
      });
    } else {
      current(e);
      visible(true);
    }
  }

  void onCancel() {
    if (visible.value) {
      visible(false);
    }
  }

  @override
  Widget builder(BuildContext context) {
    naviTitle = '我的农机';

    return Stack(
      children: [
        SizedBox(
          width: 375.w,
          child: Obx(
            () => AMap(
              machineryList: machineryList.value,
              machinery: machinery.value,
              onCancel: onCancel,
              onClick: onClick,
            ),
          ),
        ),
        Obx(
          () => Visibility(
            visible: visible.value,
            child: Positioned(
              bottom: 0,
              child: Container(
                width: 375.w,
                padding: EdgeInsets.symmetric(horizontal: 15.w, vertical: 30.h),
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(20.w),
                        topRight: Radius.circular(20.w)),
                    color: Colors.white),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    GestureDetector(
                      onTap: () {
                        goBack();
                      },
                      child: Text(
                        '<<农机列表',
                        style: TextStyle(
                            color: const Color(0xff666666),
                            fontSize: 15.sp,
                            fontWeight: FontWeight.bold),
                      ),
                    ),
                    Container(
                      margin: EdgeInsets.only(top: 30.h, bottom: 20.h),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text(
                            current.value.name.toString(),
                            style: TextStyle(
                                color: const Color(0xff222222),
                                fontSize: 18.sp,
                                fontWeight: FontWeight.bold),
                          ),
                          GestureDetector(
                            onTap: () {
                              goDetail();
                            },
                            child: Text(
                              '详情>>',
                              style: TextStyle(
                                  color: const Color(0xff666666),
                                  fontSize: 15.sp,
                                  fontWeight: FontWeight.bold),
                            ),
                          )
                        ],
                      ),
                    ),
                    Row(
                      children: [
                        Container(
                          margin: EdgeInsets.only(right: 8.w),
                          child: Image.asset(
                            'images/index/position.png',
                            width: 17.w,
                          ),
                        ),
                        Expanded(
                          flex: 1,
                          child: Text(
                            '当前位置：${current.value.address ?? ''.toString()}',
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 15.sp,
                              color: const Color(0xff222222),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ],
    );
  }
}
