import 'package:dotted_border/dotted_border.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:flutter_picker/Picker.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:worker_client/models/bankCardList.dart';
import 'package:worker_client/models/bankPickerList.dart';
import 'package:worker_client/models/entities/BankCard.dart';
import 'package:worker_client/services/bank.dart';
import 'package:worker_client/widgets/MoneyCard/index.dart';
import 'package:worker_client/widgets/MyButton/index.dart';
import 'package:worker_client/widgets/MyTitle/index.dart';
import 'package:worker_client/widgets/layout/BasicPage.dart';

class MyWithdrawal extends BasicPage {
  MyWithdrawal({Key? key}) : super(key: key) {
    naviTitle = '我的钱包';
    isPop = true;
  }

  final withdrawal = Rx<Map>({});
  final amounts = Rx<double>(0);
  int index = 0;
  BankPickerListController bankPickerListStore = BankPickerListController.t;
  BankCardListController bankCardListStore = BankCardListController.t;

  void headleWithdrawal() {
    if (withdrawal.value['money'] != null &&
        double.parse(withdrawal.value['money'].toString()) <
            amounts.value / 100) {
      if (withdrawal.value['accountCardNo'] != null) {
        EasyLoading.show(
          status: '申请中...',
          maskType: EasyLoadingMaskType.black,
        );
        var data = {...withdrawal.value};
        data.remove('ownerBank');
        data['money'] = double.parse(data['money'].toString()) * 100;
        addWithdrawal(data).then((value) {
          EasyLoading.dismiss();
          Fluttertoast.showToast(msg: '提交成功，平台审核后1到3个工作日到账！');
          Get.back();
        }).catchError((onError) {
          EasyLoading.dismiss();
          Fluttertoast.showToast(msg: onError.error['message']);
        });
      } else {
        Fluttertoast.showToast(msg: '请选择您的银行卡！');
      }
    } else {
      Fluttertoast.showToast(msg: '请输入正确的金额！');
    }
  }

  void goAddBank() {
    Get.toNamed('/addBankCard');
  }

  @override
  void beforeShow() {
    super.beforeShow();
    if (Get.arguments != null) {
      amounts(double.parse(Get.arguments['amounts'].toString()));
    }
    int itemlength = 0;
    if (bankPickerListStore.bankPickerList.value.isEmpty) {
      getBankCardList({'pageSize': 500}).then(
        (value) {
          dynamic list = <BankCardModel>[];
          List pickerList = [];
          value['records'].forEach(
            (item) {
              list.add(BankCardModel.fromJson(item));
              itemlength =
                  BankCardModel.fromJson(item).cardNo.toString().length;
              pickerList.add(BankCardModel.fromJson(item).ownerBank! +
                  '(' +
                  BankCardModel.fromJson(item)
                      .cardNo
                      .toString()
                      .substring(itemlength - 4, itemlength) +
                  ')');
            },
          );
          bankPickerListStore.bankPickerList(pickerList);
          bankCardListStore.bankCardList(list);
        },
      ).catchError(
        (error) {
          Fluttertoast.showToast(msg: error.error['message']);
        },
      );
    }
  }

  showPicker(BuildContext context) {
    Picker picker = Picker(
      height: 295.w,
      itemExtent: 40.h,
      adapter: PickerDataAdapter<String>(
          pickerdata: bankPickerListStore.bankPickerList.value),
      selecteds: [index],
      changeToFirst: false,
      onCancel: () {},
      confirmText: '确定',
      cancelText: '取消',
      cancelTextStyle: const TextStyle(color: Color(0xff7f7f7f), fontSize: 20),
      confirmTextStyle: const TextStyle(color: Color(0xff07c160), fontSize: 20),
      textStyle: const TextStyle(color: Color(0xff191919), fontSize: 20),
      selectedTextStyle:
          const TextStyle(color: Color(0xff191919), fontSize: 20),
      onConfirm: (Picker picker, List<int> value) {
        index = value.first;
        withdrawal(
          {
            ...withdrawal(),
            'ownerBank': bankCardListStore.bankCardList.value[index].ownerBank
                .toString(),
            'accountCardNo':
                bankCardListStore.bankCardList.value[index].cardId.toString(),
            'text':
                bankCardListStore.bankCardList.value[index].cardNo.toString()
          },
        );
      },
    );
    picker.showModal(context);
  }

  @override
  Widget builder(BuildContext context) {
    return Column(
      children: [
        Expanded(
          flex: 1,
          child: ListView(
            padding: EdgeInsets.only(top: 15.h, left: 15.w, right: 15.w),
            children: [
              MoneyCard(
                type: true,
                amounts: amounts.value,
                goWithDrawal: () {},
              ),
              const MyTitle(title: '选择银行卡'),
              Obx(
                () => bankPickerListStore.bankPickerList.value.isNotEmpty
                    ? GestureDetector(
                        child: Container(
                          height: 54.h,
                          padding: EdgeInsets.symmetric(horizontal: 15.w),
                          margin: EdgeInsets.only(top: 15.h),
                          decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(20.w),
                            border: Border.all(
                              color: const Color(0xffF2F2F2),
                              width: 1.w,
                            ),
                          ),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                            children: [
                              Text(
                                withdrawal.value['ownerBank'] == null
                                    ? '请选择银行'
                                    : withdrawal.value['ownerBank'].toString() +
                                        '(' +
                                        withdrawal.value['text']
                                            .toString()
                                            .substring(
                                                withdrawal.value['text']
                                                        .toString()
                                                        .length -
                                                    4,
                                                withdrawal.value['text']
                                                    .toString()
                                                    .length) +
                                        ')',
                                style: TextStyle(
                                  fontSize: 16.sp,
                                  fontWeight: FontWeight.w500,
                                  color: const Color(0xff333333),
                                ),
                              ),
                              Image.asset(
                                'images/main/goto.png',
                                height: 18.h,
                                fit: BoxFit.cover,
                              )
                            ],
                          ),
                        ),
                        onTap: () {
                          showPicker(context);
                        },
                      )
                    : Container(
                        margin: EdgeInsets.only(top: 15.h),
                        child: GestureDetector(
                          onTap: () {
                            goAddBank();
                          },
                          child: DottedBorder(
                            borderType: BorderType.RRect,
                            color: const Color(0xffBFBFBF),
                            radius: Radius.circular(20.w),
                            dashPattern: const [3, 3, 3, 3],
                            child: ClipRRect(
                              child: SizedBox(
                                height: 49.h,
                                child: Row(
                                  mainAxisAlignment: MainAxisAlignment.center,
                                  children: [
                                    Padding(
                                      padding:
                                          EdgeInsets.fromLTRB(0, 0, 10.w, 0),
                                      child: Image.asset(
                                        'images/bank/addBank.png',
                                        width: 18.w,
                                        fit: BoxFit.cover,
                                      ),
                                    ),
                                    Text(
                                      '添加银行卡',
                                      style: TextStyle(
                                          fontWeight: FontWeight.bold,
                                          fontSize: 16.sp,
                                          color: const Color(0xff323232)),
                                    ),
                                  ],
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
              ),
              const MyTitle(title: '提取金额'),
              Container(
                height: 54.h,
                padding: EdgeInsets.symmetric(horizontal: 15.w),
                margin: EdgeInsets.only(top: 15.h),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20.w),
                  border: Border.all(
                    color: const Color(0xffF2F2F2),
                    width: 1.w,
                  ),
                ),
                child: Row(
                  children: [
                    Padding(
                      padding: EdgeInsets.only(right: 10.w),
                      child: Text(
                        '￥',
                        style: TextStyle(
                          fontSize: 24.sp,
                          fontWeight: FontWeight.w500,
                          color: const Color(0xff333333),
                        ),
                      ),
                    ),
                    Expanded(
                      child: TextField(
                        keyboardType: TextInputType.number,
                        decoration: const InputDecoration(
                          contentPadding: EdgeInsets.symmetric(vertical: 1),
                          hintText: '请输入提现金额',
                          border:
                              OutlineInputBorder(borderSide: BorderSide.none),
                        ),
                        onChanged: (e) {
                          withdrawal.value['money'] = e;
                        },
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
        Padding(
          padding: EdgeInsets.only(bottom: 16.h + 15.w),
          child: MyButton(
            pwith: 30.w,
            text: '提现',
            type: 0,
            disable: false,
            onClick: () {
              headleWithdrawal();
            },
          ),
        ),
      ],
    );
  }
}
