import 'package:amap_flutter_map/amap_flutter_map.dart';
import 'package:amap_flutter_base/amap_flutter_base.dart';
import 'package:flutter/widgets.dart';
import 'package:worker_client/models/entities/Machinery.dart';
import '/utils/amap/const_config.dart';

// https://developer.amap.com/api/flutter/guide/map-flutter-plug-in/map-flutter-info
class AMap extends StatelessWidget {
  late AMapController _mapController;
  final List<Machinery> machineryList;
  final Machinery machinery;
  dynamic centerLocationArea = [];
  final Map<String, Marker> _markers = Map<String, Marker>();
  final Function onClick;
  final Function onCancel;

  AMap({
    Key? key,
    required this.machineryList,
    required this.machinery,
    required this.onClick,
    required this.onCancel,
  }) : super(key: key);

  void onMapCreated(AMapController controller) {
    _mapController = controller;
  }

  BitmapDescriptor m1 =
      BitmapDescriptor.fromIconPath("images/machinery/greenMachinery.png");
  BitmapDescriptor m2 =
      BitmapDescriptor.fromIconPath("images/machinery/orangeMachinery.png");
  BitmapDescriptor m3 =
      BitmapDescriptor.fromIconPath("images/machinery/repairMachinery.png");
  void _initMarkers() {
    if (machineryList.isNotEmpty && machinery.location != null) {
      centerLocationArea = machinery.location!.split(',');

      dynamic locationArea = [];
      for (var item in machineryList) {
        locationArea = item.location!.split(',');
        Marker marker = Marker(
            onTap: (e) {
              onClick(item);
            },
            //这个东西在苹果手机上会有个默认气泡 false后就正常了
            infoWindowEnable: false,
            clickable: true,
            position: LatLng(
                double.parse(locationArea[0]), double.parse(locationArea[1])),
            icon: item.status == 0
                ? m3
                : (item.jobStatus == null || item.jobStatus == 3)
                    ? m2
                    : m1);
        _markers[item.machineryId.toString()] = marker;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    _initMarkers();

    return centerLocationArea.length != 0
        ? AMapWidget(
            privacyStatement: ConstConfig.amapPrivacyStatement,
            apiKey: ConstConfig.amapApiKeys,
            markers: Set<Marker>.of(_markers.values),
            onPoiTouched: (e) {},
            onCameraMove: (e) {
              // 移动地图
              onCancel();
            },
            // 默认是邓州市中心
            initialCameraPosition: CameraPosition(
                target: LatLng(double.parse(centerLocationArea[0].toString()),
                    double.parse(centerLocationArea[1].toString())),
                zoom: 13),
          )
        : const SizedBox(
            width: 1,
            height: 1,
          );
  }
}
